#!/usr/bin/env python3
#                            _                _____ 
#      /\                   | |       /\     |_   _|
#     /  \     ____   __ _  | |_     /  \      | |  
#    / /\ \   |_  /  / _` | | __|   / /\ \     | |  
#   / ____ \   / /  | (_| | | |_   / ____ \   _| |_ 
#  /_/    \_\ /___|  \__,_|  \__| /_/    \_\ |_____|
#                                         
#                        


__title__ = 'startpkg'
__description__ = 'AzatAI Start Package Tool (startpkg)'
__url__ = 'https://github.com/AzatAI/startpkg'
__version__ = '0.1.5'
__author__ = 'Yaakov Azat'
__author_email__ = 'yaakovazat@gmail.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2020 Azat Artificial Intelligence, LLP (AzatAI)'